@@ -1,5 +1,5 @@
-version_info = (0, 9, 12)
-__version__ = ".".join(map(str, version_info))
+version_info = (0, 15, 2)
+__version__ = '.'.join(map(str, version_info))
 
 try:
     from eventlet import greenthread
@@ -15,18 +15,18 @@ try:
     spawn_n = greenthread.spawn_n
     spawn_after = greenthread.spawn_after
     kill = greenthread.kill
-    
+
     Timeout = timeout.Timeout
     with_timeout = timeout.with_timeout
-    
+
     GreenPool = greenpool.GreenPool
     GreenPile = greenpool.GreenPile
-    
+
     Queue = queue.Queue
-    
+
     import_patched = patcher.import_patched
     monkey_patch = patcher.monkey_patch
-    
+
     connect = convenience.connect
     listen = convenience.listen
     serve = convenience.serve
@@ -34,12 +34,16 @@ try:
     wrap_ssl = convenience.wrap_ssl
 
     getcurrent = greenlet.greenlet.getcurrent
-    
-    # deprecated    
+
+    # deprecated
     TimeoutError = timeout.Timeout
     exc_after = greenthread.exc_after
     call_after_global = greenthread.call_after_global
-except ImportError:
-    # this is to make Debian packaging easier
-    import traceback
-    traceback.print_exc()
+except ImportError as e:
+    # This is to make Debian packaging easier, it ignores import
+    # errors of greenlet so that the packager can still at least
+    # access the version.  Also this makes easy_install a little quieter
+    if 'greenlet' not in str(e):
+        # any other exception should be printed
+        import traceback
+        traceback.print_exc()
